@@ -93,6 +93,12 @@ from tabulate import tabulate
     """,
     is_flag=True
 )
+@click.option(
+    "--ignore-new-tests",
+    "ignore_new_tests",
+    help='Ignore tests that were added recently.\n\nNOTICE: this option will ignore tests that you added just now as well',
+    is_flag=True
+)
 @click.pass_context
 def subset(
     context: click.core.Context,
@@ -106,6 +112,7 @@ def subset(
     confidence: Optional[PercentageType],
     split: bool,
     no_base_path_inference: bool,
+    ignore_new_tests: bool,
 ):
 
     session_id = find_or_create_session(context, session, build_name, flavor)
@@ -218,11 +225,15 @@ def subset(
                 "session": {
                     # expecting just the last component, not the whole path
                     "id": os.path.basename(session_id)
-                }
+                },
+                "ignoreNewTests": ignore_new_tests,
             }
 
             if target is not None:
-                payload["target"] = target
+                payload["goal"] = {
+                    "type": "subset-by-percentage",
+                    "percentage": target,
+                }
             elif duration is not None:
                 payload["goal"] = {
                     "type": "subset-by-absolute-time",
@@ -264,6 +275,7 @@ def subset(
                         "post", "subset", timeout=timeout, payload=payload, compress=True)
 
                     res.raise_for_status()
+
                     output = res.json()["testPaths"]
                     rests = res.json()["rest"]
                     subset_id = res.json()["subsettingId"]
@@ -289,7 +301,7 @@ def subset(
             else:
                 self.output_handler(output, rests)
 
-            # When Launchable returns an error, the cli skips showing summary report 
+            # When Launchable returns an error, the cli skips showing summary report
             if "subset" not in summary.keys() or "rest" not in summary.keys():
                 return
 
