@@ -50,3 +50,7 @@ def subset(client):
 
     client.separator = "|"
     client.run()
+
+
+split_subset = launchable.CommonSplitSubsetImpls(
+    __name__, seperator="|").split_subset()
